@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-global.c,v 1.85 2015/12/22 13:59:30 enlf Exp $
+/* $Id$
  */
 
 /*
-   Copyright (C) 1997-2016 by Erik Nolf
+   Copyright (C) 1997-2018 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -50,14 +50,8 @@ const char  *MDC_VERSION = XMEDCON_VERSION;
 const char  *MDC_LIBVERS = XMEDCON_LIBVERS;
 
 /* fill in host endian and default write endian */
-#if MDC_WORDS_BIGENDIAN
-Int8 MDC_HOST_ENDIAN = MDC_BIG_ENDIAN;
-Int8 MDC_WRITE_ENDIAN= MDC_BIG_ENDIAN;
-#else
-Int8 MDC_HOST_ENDIAN = MDC_LITTLE_ENDIAN;
-Int8 MDC_WRITE_ENDIAN= MDC_LITTLE_ENDIAN;
-#endif
-
+Int8 MDC_HOST_ENDIAN = -1;
+Int8 MDC_WRITE_ENDIAN= -1;
 Int8 MDC_FILE_ENDIAN = -1;
 
 Int8 MDC_BLOCK_MESSAGES = MDC_NO;
